import getdata
import json
class Person():
    mid = ""
    need = ["mid","name","sex","sign","level","birthday","coins","following","follower","black"]#following关注数,follower,粉丝数,"black",黑名单
    def __init__(self,mid):
        self.mid = mid

    def getbasic(self):
        info = {}
        url = "https://api.bilibili.com/x/space/acc/info?mid="+self.mid+"&jsonp=jsonp"
        dict_json=getdata.getdict(url)

        if dict_json["code"] != 0:
            raise Exception("invalid mid")
        else:
            for i,j in dict_json["data"].items():
                if i in self.need:
                    info[i]=j

        url = "https://api.bilibili.com/x/relation/stat?vmid="+self.mid+"&jsonp=jsonp"
        dict_json=getdata.getdict(url)
        if dict_json["code"] != 0:
            raise Exception("invalid mid")
        else:
            for i,j in dict_json["data"].items():
                if i in self.need:
                    info[i]=j
        return info

class up(Person):
    sumcount = 0
    videolist = []
    videotype ={}#用来表示用户有多少稿件,每个稿件是什么区的
    moreinfo = {}#有些数据无法通过前面api获得,只能这么搞关于发布时间和时长之类的
    videoneed = ["created","length","is_union_video","typeid"]
    def __init__(self,mid):
        super(Person,self).__init__()
        self.mid =mid

    def getvideos(self):
        pn = 1
        page =100
        url = "https://api.bilibili.com/x/space/arc/search?mid="+self.mid+"&;pn=1&ps=100&jsonp=jsonp"
        dict_json=getdata.getdict(url)
        if dict_json["code"] != 0 :
            raise Exception("can't do that")
        jsgood=json.dumps(dict_json["data"]["list"],indent=1,ensure_ascii=False)
        print(jsgood)
        self.videotype = dict_json["data"]["list"]["tlist"]
        for key,value in self.videotype.items():
            self.sumcount += value["count"]
        for i in dict_json["data"]["list"]["vlist"]:
            self.videolist.append(str(i["aid"]))
            self.moreinfo[i["aid"]] = {}
            for keyj,valuej in i.items():
                if keyj in self.videoneed:
                    self.moreinfo[i["aid"]][keyj] = valuej

        while page<self.sumcount:
            pn+=1
            page+=100
            url = "https://api.bilibili.com/x/space/arc/search?mid="+self.mid+"&;pn="+str(pn)+"&ps=100&jsonp=jsonp"
            dict_json=getdata.getdict(url)
            if dict_json["code"] != 0 :
                raise Exception("can't do that")
            for i in dict_json["data"]["list"]["vlist"]:
                self.videolist.append(str(i["aid"]))
                for keyj,valuej in i.items():
                    if keyj in self.videoneed:
                        self.moreinfo[i["aid"]][keyj] = valuej
        return self.videolist
    def timetranslate(self):
        if self.moreinfo !={}:
            for key,value in self.moreinfo.items():
                value["created"] = getdata.gettime(value["created"])
            print("translate time successful")
        else:
            print("can't translate")




import requests
import json
from translate import translate

def printspace(deep):
    print(deep,end="")
    for i in range(deep):
        print("    ",end ="")
def prints(data,deep):
    q ={}
    z= []
    if type(data) != type(q):
        printspace(deep)
        print(data)
        return
    for i in data.keys():
        newdata = data[i]
        if type(q) == type(newdata):
            printspace(deep)
            print(i)
            prints(newdata, deep+1)
        else:
            printspace(deep)
            print(i)
        if type(z)== type(newdata):
            for j in newdata:
                prints(j, deep+1)
trans = translate()
trans.getbv("BV197411d7uG")
av = trans.putav()
url = "https://api.bilibili.com/x/space/arc/search?mid=349550991&;pn=1&ps=25&jsonp=jsonp "
#已知bv


# url = "http://api.bilibili.com/x/v2/reply?jsonp=jsonp&;type=1&oid="+str(av)

p = requests.get(url)
q ={}
print(type(q))
res_p = p.content.decode()
dict_json = json.loads(res_p)
# # for i in dict_json.keys():
# #     if type(dict_json[i]) == type(q):
# #         for i in dict_json[i].keys():
# #             print(i)
# times =0
# answer = {}
# for i in dict_json["data"]["replies"]:
#     print(i["member"]["uname"])
#     print(i["member"]["level_info"]["current_level"])
#     answer[i["content"]["message"]] = []
#     if i["replies"] !=None:
#         for j  in i["replies"]:
#             answer[i["content"]["message"]].append(j["content"]["message"])

# print(answer)

print(dict_json)




from spyderbi import translate
import getdata
import requests
import json
class video():
    av = ""
    bv = ""
    mid_reply = {}#每一句回复所对应的id
    def __init__(self,*args):
        for i in args:
            if i[0:2]=="BV":
                self.bv = i
            else:
                self.av = i
        if self.av!="" and self.bv =="":
                self.bv = translate.enc(self.av)

        if self.bv!="" and self.av =="":
                self.av = translate.dec(self.bv)


    def getav(self,av):
        self.av = av
        self.bv = translate.enc(self.av)

    def getbv(self,bv):
        self.bv = av
        self.av = translate.dec(self.bv)

    def putav(self):
        return self.av

    def putbv(self):
        return self.bv



    def check(self):
        if self.av =="":
            raise NameError("you should set av")
    def getbasic(self):
        self.check()
        answer = {}
        url = "http://api.bilibili.com/archive_stat/stat?aid="+self.av+"&type=jsonp"
        dict_json = getdata.getdict(url)
        answer = dict_json["data"]
        if dict_json["code"] != 0:
            raise Exception("请求错误,请重新检查")
        url = "https://api.bilibili.com/x/web-interface/view?aid="+self.av# 关于视频类的,这段更重要,以后有需要,直接看这段就好
        dict_json = getdata.getdict(url)
        if dict_json["code"] != 0:
            raise Exception("请求错误,请重新检查")
        answer["videos"] = dict_json["data"]["videos"]
        answer["tid"] = dict_json["data"]["tid"]
        answer["tname"] = dict_json["data"]["tname"]
        answer["copyright"] = dict_json["data"]["copyright"]
        answer["title"] = dict_json["data"]["title"]
        answer["desc"] = dict_json["data"]["desc"] #视频简介
        return answer




    def getbasicinfo(self):
        params = {"aid":"av值","view":"播放量","danmaku":"弹幕量","reply":"回复数","favorite":"收藏数","coin":"硬币数","share":"分享数","like":"点赞数","copyright":"1自制2转载"}
        for key,value in params.items():
            print(key,"    ",value)

    def gettag(self):
        self.check()
        url = "http://api.bilibili.com/x/tag/archive/tags?aid="+self.av+"&jsonp=jsonp "
        dict_json = getdata.getdict(url)
        if dict_json["code"] != 0:
            raise Exception("请求错误,请重新检查")
        else:
            dictinfo = {}
            for i in dict_json["data"]:
                dictinfo[i["tag_name"]] = i["tag_id"]
            return dictinfo
    def gettaginfo(self):
        print("标签名称    标签id")

    def getdict(self,page,av):
        url = "http://api.bilibili.com/x/v2/reply?jsonp=jsonp&;pn="+page+"&type=1&oid="+av
        p = requests.get(url)
        res_p = p.content.decode()
        return json.loads(res_p)

    def getreply(self,count):
        self.check()
        url ="http://api.bilibili.com/x/v2/reply?jsonp=jsonp&;pn=1"+"&type=1&oid="+self.av
        need = count
        times = 0
        num = 1
        flag = True
        answer = {}#{'来了来了': ['回复 @panda_face :df', '感谢老铁支持'], '想不出骚话': [], '百万后期，不得了': ['这么早就看了？？？']}
        id_answer = {}
        dict_json = self.getdict(str(num), self.av)
        if dict_json["code"] != 0:
            raise Exception("此视频不支持此api")
        while  dict_json["data"]["replies"] != None and flag:
            for i in dict_json["data"]["replies"]:
                if i["content"]["message"] not in answer.keys():
                    answer[i["content"]["message"]] = []
                    id_answer[i["content"]["message"]] = []
                id_answer[i["content"]["message"]].append(i["mid"])
                if i["replies"] !=None:
                    for j  in i["replies"]:
                        answer[i["content"]["message"]].append(j["content"]["message"])
                times += 1
                if times == need:
                    flag =False
                    break
            print("第"+str(num)+"页下载成功")
            num +=1
            dict_json = self.getdict(str(num), self.av)
        self.mid_reply = id_reply
        return answer





__table = 'fZodR9XQDSUm21yCkr6zBqiveYah8bt4xsWpHnJE7jL5VG3guMTKNPAwcF'
tr = {}
for i in range(58):
    tr[__table[i]] = i
s = [11, 10, 3, 8, 4, 6]
xor = 177451812
add = 8728348608
av = ""
bv = ""

def dec(x):
    r = 0
    for i in range(6):
        r += tr[x[s[i]]]*58**i
    return str((r-add) ^ xor)

def enc(x):
    x= int(x)
    x = (x ^ xor)+add
    r = list('BV1  4 1 7  ')
    for i in range(6):
        r[s[i]] = __table[x//58**i % 58]
    return ''.join(r)








import json
import requests
import time

def getdict(url):
    p = requests.get(url)
    res_p = p.content.decode()
    return json.loads(res_p)

def gettime(timeStamp,style="%Y--%m--%d %H:%M:%S"):
    timeArray = time.localtime(timeStamp)
    otherStyleTime = time.strftime(style, timeArray)
    return otherStyleTime
